@@ -1,5 +1,6 @@
 #include "fooddialog.h"
 #include <QtDebug>
+
 FoodDialog::FoodDialog(QWidget *parent)
 {
     setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -20,7 +21,7 @@ FoodDialog::FoodDialog(QWidget *parent)
     selectorType = new QMaemo5ListPickSelector;
     selectorType->setModel(modelType);
     btnType->setPickSelector(selectorType);
-
+    connect(selectorType,SIGNAL(Selected(QString)), this, SLOT(load(QString)));
     modelName = new QStandardItemModel(this);
 
     btnName = new QMaemo5ValueButton("Product");
@@ -53,9 +54,9 @@ FoodDialog::FoodDialog(QWidget *parent)
 
 }
 
-void FoodDialog::load()
+void FoodDialog::load(QString type)
 {
-    QList <QString> food = xml->openIngredients();
+    QList <QString> food = xml->openIngredients(type);
     modelName->clear();
     while(!food.isEmpty())
     {
