@@ -5,13 +5,14 @@ HistoryInfoWindow::HistoryInfoWindow(QWidget *parent) :
 {
     QString set;
     setAttribute(Qt::WA_Maemo5StackedWindow);
+    setAttribute(Qt::WA_Maemo5PortraitOrientation);
 
     QWidget *widget = new QWidget();
     QVBoxLayout *vLayout = new QVBoxLayout();
 
-    for(int i = 1; i < 10 ; i++)
+    for(int i = 0; i < 9; i++)
     {
-        set.setNum(i);
+        set.setNum(i+1);
         lblSet[i] = new QLabel("Set " + set + ": No info.");
         vLayout->addWidget(lblSet[i]);
     }
@@ -33,6 +34,9 @@ void HistoryInfoWindow::load(QString name, QString group, QString date)
 
     list = xml->getHistoryByExercise(name, date);
 
+    if(list.isEmpty())
+        return;
+
     while(!list.isEmpty())
     {
         set.setNum(j+1);
