@@ -1442,7 +1442,7 @@ QList<QString> XML::openGroup(QString group)
     return readInfo;
 }
 
-QList<QString> XML::openIngredients()
+QList<QString> XML::openIngredients(QString type)
 {
     QList<QString> readInfo;
     readInfo.clear();
@@ -1474,7 +1474,8 @@ QList<QString> XML::openIngredients()
       {
         if( e.tagName() == "ingredient" )
         {
-            readInfo.append(e.attribute("name", ""));
+            if(e.attribute("type","") == type)
+                readInfo.append(e.attribute("name", ""));
         }
       }
       n = n.nextSibling();
